@@ -1,23 +1,8 @@
 /*
- * Copyright 2015  Kevin Funk <kfunk@kde.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License or (at your option) version 3 or any later version
- * accepted by the membership of KDE e.V. (or its successor approved
- * by the membership of KDE e.V.), which shall act as a proxy
- * defined in Section 14 of version 3 of the license.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    SPDX-FileCopyrightText: 2015 Kevin Funk <kfunk@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #pragma once
 
@@ -61,11 +46,12 @@ Q_SIGNALS:
     void showMessage(KDevelop::IStatus*, const QString& message, int timeout = 0) override;
     void showProgress(KDevelop::IStatus*, int minimum, int maximum, int value) override;
 
+private Q_SLOTS:
+    void slotPercent(KJob* job, unsigned long percent);
+
 private:
     const QScopedPointer<class JobStatusPrivate> d_ptr;
     Q_DECLARE_PRIVATE(JobStatus)
-
-    Q_PRIVATE_SLOT(d_func(), void slotPercent(KJob*, unsigned long))
 };
 
 }
